#include "esphome/core/log.h"
#include "number_traits.h"

namespace esphome::number {

static const char *const TAG = "number";

}  // namespace esphome::number
